package com.ippon.osgi.hello;

import static com.ippon.osgi.util.LogUtil.myLog;

import java.util.IllegalFormatException;

import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.jmx.export.annotation.ManagedAttribute;
import org.springframework.jmx.export.annotation.ManagedResource;

import com.ippon.osgi.publichello.HelloWorldService;

@ManagedResource(objectName="helloworld-2-1:name=singleton")
public class HelloWorldSingleton implements HelloWorldService, InitializingBean, DisposableBean {
	
	public HelloWorldSingleton() {
	}

	private static String DEFAULT_FORMAT = "%s says Hello to %s (Second Version)";
	private String currentFormat = DEFAULT_FORMAT;
	
	@ManagedAttribute()
	public String getFormat() {
		return currentFormat;
	}

	@ManagedAttribute
	public void setFormat(String format) {
		this.currentFormat = format;
	}

	@Override
	public String saysHello(String from, String to) {

		String helloWorldStr = "";
		try {
			helloWorldStr = String.format(currentFormat, from,to);
		} catch (IllegalFormatException e) {
			helloWorldStr = String.format(DEFAULT_FORMAT, from, to);
		}
		myLog("[HelloWorldSingleton 2.1 (@" + Integer.toHexString(hashCode()) + ")] : " + helloWorldStr);
		
		return helloWorldStr;
	}
	
	@Override
	public void afterPropertiesSet() throws Exception {
		myLog("HelloWorldSingleton 2.1 (@"+Integer.toHexString(hashCode())+") initialized by Spring");
	}

	@Override
	public void destroy() throws Exception {
		myLog("HelloWorldSingleton 2.1 (@"+Integer.toHexString(hashCode())+") destroyed by Spring");		
	}

	
}
